@@ -41,6 +41,9 @@ mod rtsp_client;
 mod rtsp_context;
 mod rtsp_media;
 mod rtsp_media_factory;
+#[cfg(any(feature = "v1_14", feature = "dox"))]
+#[cfg_attr(feature = "dox", doc(cfg(feature = "v1_14")))]
+mod rtsp_onvif_media_factory;
 mod rtsp_server;
 mod rtsp_session_pool;
 mod rtsp_thread;
@@ -129,6 +132,9 @@ pub mod prelude {
     pub use crate::rtsp_client::RTSPClientExtManual;
     pub use crate::rtsp_media::RTSPMediaExtManual;
     pub use crate::rtsp_media_factory::RTSPMediaFactoryExtManual;
+    #[cfg(any(feature = "v1_14", feature = "dox"))]
+    #[cfg_attr(feature = "dox", doc(cfg(feature = "v1_14")))]
+    pub use crate::rtsp_onvif_media_factory::RTSPOnvifMediaFactoryExtManual;
     pub use crate::rtsp_server::RTSPServerExtManual;
     pub use crate::rtsp_session_pool::RTSPSessionPoolExtManual;
 }
